==> u++_5.0.1.orig.tar.gz: u++-5.0.1/src/scheduler/uStaticPIQ.h <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.0.1, Copyright (C) Ashif S. Harji 2000
// 
// uStaticPIQ.h -- 
// 
// Author           : Ashif S. Harji
// Created On       : Fri Jan 14 17:53:22 2000
// Last Modified By : Peter A. Buhr
// Last Modified On : Thu Jun 28 16:55:34 2001
// Update Count     : 25
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_STATICPIQ_H__
#define __U_STATICPIQ_H__

#pragma __U_NOT_USER_CODE__


//#include <uDebug.h>

#include <uHeap.h>


// TEMPORARY: where should this be defined??
#define __U_MAX_NUMBER_PRIORITIES__ 32


class uStaticPIQ : public uBasePIQ {
    int uObjects[ __U_MAX_NUMBER_PRIORITIES__ ];
    uSpinLock lock;
    unsigned int uMask;
    
    static int compare(int k1, int k2);
  public:
    uStaticPIQ();
    virtual bool uEmpty() const;
    //virtual int uHead();
    virtual int uGetHighestPriority();
    virtual void uAdd( int priority );
    virtual int uDrop();
    virtual void uRemove( int priority ); 
}; // PIHeap


#endif // __U_STATICPIQ_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //

==> u++_5.3.0.orig.tar.gz: u++-5.3.0/src/scheduler/uStaticPIQ.h <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.3.0, Copyright (C) Ashif S. Harji 2000
// 
// uStaticPIQ.h -- 
// 
// Author           : Ashif S. Harji
// Created On       : Fri Jan 14 17:53:22 2000
// Last Modified By : Peter A. Buhr
// Last Modified On : Mon Oct 10 10:29:38 2005
// Update Count     : 30
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __U_STATICPIQ_H__
#define __U_STATICPIQ_H__

#pragma __U_NOT_USER_CODE__


//#include <uDebug.h>

#include <uHeap.h>


// TEMPORARY: where should this be defined??
#define __U_MAX_NUMBER_PRIORITIES__ 32


class uStaticPIQ : public uBasePIQ {
    int uObjects[ __U_MAX_NUMBER_PRIORITIES__ ];
    uSpinLock lock;
    unsigned int uMask;
    
    static int compare(int k1, int k2);
  public:
    uStaticPIQ();
    virtual bool empty() const;
    //virtual int head();
    virtual int uGetHighestPriority();
    virtual void add( int priority );
    virtual int drop();
    virtual void remove( int priority ); 
}; // PIHeap


#endif // __U_STATICPIQ_H__


// Local Variables: //
// compile-command: "gmake install" //
// End: //
